.. raw:: html

   <div align="center">
   <img src="docs/logo.png" width="450px">
   </img>
   <br/>
   </div>
   <br/><br/>

Cloud code for exoplanet atmospheres.


.. image:: https://travis-ci.com/natashabatalha/virga.svg?token=rhFPvNo2sGUpKx2Zyx86&branch=master
    :target: https://travis-ci.com/natashabatalha/virga
